summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_remote_scheduler.py
diff options
context:
space:
mode:
authorMattia Rizzolo <mattia@debian.org>2017-04-12 15:23:31 +0200
committerMattia Rizzolo <mattia@debian.org>2017-04-12 15:23:46 +0200
commit77ff2abfad370f6fde62554ede127d398b23765e (patch)
treea504a48b858316e80b95c33a978dff09c2805bee /bin/reproducible_remote_scheduler.py
parente32380742425313817f235ed1774a45ea9c2752f (diff)
downloadjenkins.debian.net-77ff2abfad370f6fde62554ede127d398b23765e.tar.xz
Revert "reproducible debian: temporarily rise the schedule limit (again)"
This reverts commit e32380742425313817f235ed1774a45ea9c2752f. Signed-off-by: Mattia Rizzolo <mattia@debian.org>
Diffstat (limited to 'bin/reproducible_remote_scheduler.py')
-rwxr-xr-xbin/reproducible_remote_scheduler.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_remote_scheduler.py b/bin/reproducible_remote_scheduler.py
index 2164bbb6..cd1eaad6 100755
--- a/bin/reproducible_remote_scheduler.py
+++ b/bin/reproducible_remote_scheduler.py
@@ -212,7 +212,7 @@ date = (now - time_delta).strftime('%Y-%m-%d %H:%M')
log.debug('date_scheduled = ' + date + ' time_delta = ' + str(time_delta))
# a single person can't schedule more than 2000 packages in the same day; this
# is actually easy to bypass, but let's give some trust to the Debian people
query = """SELECT count(*) FROM manual_scheduler
WHERE requester = '{}' AND date_request > '{}'"""
@@ -221,7 +221,7 @@ try:
except IndexError:
amount = 0
log.debug(requester + ' already scheduled ' + str(amount) + ' packages today')
-if amount + len(ids) > 2000 and not local:
+if amount + len(ids) > 200 and not local:
log.error(bcolors.FAIL + 'You have exceeded the maximum number of manual ' +
'reschedulings allowed for a day. Please ask in ' +
'#debian-reproducible if you need to schedule more packages.' +
@@ -212,7 +212,7 @@ date = (now - time_delta).strftime('%Y-%m-%d %H:%M')
log.debug('date_scheduled = ' + date + ' time_delta = ' + str(time_delta))
-# a single person can't schedule more than 2000 packages in the same day; this
+# a single person can't schedule more than 200 packages in the same day; this
# is actually easy to bypass, but let's give some trust to the Debian people
query = """SELECT count(*) FROM manual_scheduler